#!/bin/bash
set -e
set -o pipefail

function pip-plugin () {
  pip3 install "git+${1}@${2}"
}

function ninja-plugin () {
  tempdir="${3}"
  if [[ "${tempdir}" == "" ]]; then
    tempdir="$(mktemp -p /src -d -t vsXXXXXX)"
  fi
  git-shallow-clone "${2}" "${1}" "${tempdir}"
  pushd "${tempdir}"
  mkdir b
  pushd b
  meson -Dlibdir=/usr/lib/vapoursynth ..
  ninja
  ninja install
  popd
  popd
  if [[ "${3}" == "" ]]; then
    rm -r "${tempdir}"
  fi
}

function configure-plugin () {
  tempdir="${3}"
  if [[ "${tempdir}" == "" ]]; then
    tempdir="$(mktemp -p /src -d -t vsXXXXXX)"
  fi
  git-shallow-clone "${2}" "${1}" "${tempdir}"
  pushd "${tempdir}"
  ./autogen.sh
  ./configure --prefix=/usr --libdir=/usr/lib/vapoursynth
  make -j$(nproc)
  make install
  popd
  if [[ "${3}" == "" ]]; then
    rm -r "${tempdir}"
  fi
}

# VapourSynth ones

ninja-plugin https://github.com/vapoursynth/vivtc.git 4ac661d78eaf8b5ab7c5dd2d05c81234fe9aaca8
ninja-plugin https://github.com/vapoursynth/vs-removegrain.git 89ca38a6971e371bdce2778291393258daa5f03b
ninja-plugin https://github.com/vapoursynth/vs-miscfilters-obsolete.git 07e0589a381f7deb3bf533bb459a94482bccc5c7




# Irrational-Encoding-Wizardry entries

ninja-plugin https://github.com/Irrational-Encoding-Wizardry/descale.git 8c53f5d1297dee286e5a854ae5731103614a0583 /src/descale
cp /src/descale/descale.py /usr/lib/vapoursynth/

pip-plugin https://github.com/Irrational-Encoding-Wizardry/vs-tools.git 48f116f23509c2ef5015d90003ec259a625a9a6e
pip-plugin https://github.com/Irrational-Encoding-Wizardry/vs-pyplugin.git 890feeb0f75bf2dfcc214df377230e877ca9e138
pip-plugin https://github.com/Irrational-Encoding-Wizardry/vs-exprtools.git b1da8cc97f8d36b8405b127f92d9ddff6d01e9be
pip-plugin https://github.com/Irrational-Encoding-Wizardry/vs-aa.git 2f0c7308f416b63a6b26e4c84883349db4d55062
pip-plugin https://github.com/Irrational-Encoding-Wizardry/vs-denoise.git 38291d4821973bdca4d54d89a91dc4d7b1ac8e73
pip-plugin https://github.com/Irrational-Encoding-Wizardry/vs-kernels.git 531de9b9bf58d66727a332c8a960f2bddf1d0fe8
pip-plugin https://github.com/Irrational-Encoding-Wizardry/vs-scale.git b8c71d62155fdb3e89b3854e2bd2ce090891cf58
pip-plugin https://github.com/Irrational-Encoding-Wizardry/vs-rgtools.git 481184a93404778040a2a56ef1be864739988032
pip-plugin https://github.com/Irrational-Encoding-Wizardry/vs-masktools.git 8dff1177dc432ad107a1687eb07f9edc955b9bfe
pip-plugin https://github.com/Irrational-Encoding-Wizardry/vs-dehalo.git 96b578258caa6110dac4d5b77f6ed6047b1877f1
pip-plugin https://github.com/Irrational-Encoding-Wizardry/vs-deband.git aaa6803706c843ffb98c462c48f9475930584a9a
pip-plugin https://github.com/Irrational-Encoding-Wizardry/vs-deinterlace.git 5ccaf9f0e23362308b63e293534aeeda3a73b287
pip-plugin https://github.com/Irrational-Encoding-Wizardry/vs-dfft.git 1e17bc2e9d1884715c71cf56a972e4d0867cabff

curl https://raw.githubusercontent.com/Irrational-Encoding-Wizardry/fvsfunc/076dbde68227f6cca91304a447b2a02b0e95413e/fvsfunc.py > /usr/lib/vapoursynth/fvsfunc.py
sed -i 's/core\.nnedi3/core\.znedi3/' /usr/lib/vapoursynth/fvsfunc.py






# HomeOfVapourSynthEvolution entries
ninja-plugin https://github.com/HomeOfVapourSynthEvolution/VapourSynth-TDeintMod.git r10.1
ninja-plugin https://github.com/HomeOfVapourSynthEvolution/VapourSynth-Yadifmod.git r10.1
ninja-plugin https://github.com/HomeOfVapourSynthEvolution/VapourSynth-BM3D.git r9
ninja-plugin https://github.com/HomeOfVapourSynthEvolution/VapourSynth-DFTTest.git bc5e0186a7f309556f20a8e9502f2238e39179b8
ninja-plugin https://github.com/HomeOfVapourSynthEvolution/VapourSynth-DCTFilter.git r2.1
ninja-plugin https://github.com/HomeOfVapourSynthEvolution/VapourSynth-CTMF.git r5
ninja-plugin https://github.com/HomeOfVapourSynthEvolution/VapourSynth-CAS.git r2
ninja-plugin https://github.com/HomeOfVapourSynthEvolution/VapourSynth-Deblock.git r6.1
ninja-plugin https://github.com/HomeOfVapourSynthEvolution/VapourSynth-EEDI2.git r7.1
#OpenCL required: ninja-plugin https://github.com/HomeOfVapourSynthEvolution/VapourSynth-EEDI3.git r4
ninja-plugin https://github.com/HomeOfVapourSynthEvolution/VapourSynth-VMAF.git r10
#compilation error: ninja-plugin https://github.com/HomeOfVapourSynthEvolution/VapourSynth-TCAnny.git 14ac2ceeb59afc7089974d0ae233fe8d0ea183c8
ninja-plugin https://github.com/HomeOfVapourSynthEvolution/VapourSynth-AddGrain.git r10
ninja-plugin https://github.com/HomeOfVapourSynthEvolution/VapourSynth-Retinex.git 6bfbdd429159c85075dc4b08e0ac4e706470916b
ninja-plugin https://github.com/HomeOfVapourSynthEvolution/VapourSynth-TTempSmooth.git r4.1
ninja-plugin https://github.com/HomeOfVapourSynthEvolution/VapourSynth-Bwdif.git 258991085c5846e41b0ba8a128ece8bbb8a98cb8

curl https://raw.githubusercontent.com/HomeOfVapourSynthEvolution/nnedi3_resample/eb53450a19f41f8435f36099f083ede0ae836c83/nnedi3_resample.py > /usr/lib/vapoursynth/nnedi3_resample.py

pip-plugin https://github.com/HomeOfVapourSynthEvolution/havsfunc.git 0f6a7d9d9712d59b4e74e1e570fc6e3a526917f9
pip-plugin https://github.com/HomeOfVapourSynthEvolution/mvsfunc.git 865c7486ca860d323754ec4774bc4cca540a7076


git-shallow-clone "f956a1e607c492fe156aa348f00c8277b30175ad" https://github.com/HomeOfVapourSynthEvolution/VapourSynth-SangNomMod.git /src/VapourSynth-SangNomMod
pushd /src/VapourSynth-SangNomMod
./configure --install=/usr/lib/vapoursynth
make -j$(nproc)
make install

# dubhater entries
curl https://raw.githubusercontent.com/dubhater/vapoursynth-fieldhint/v3/src/fieldhint.c | gcc -x c -I /usr/include/vapoursynth \
-shared -o /usr/lib/vapoursynth/fieldhint.so \
-O3 -fPIC \
-

configure-plugin https://github.com/dubhater/vapoursynth-fluxsmooth.git v2

ninja-plugin https://github.com/dubhater/vapoursynth-sangnom.git r42
ninja-plugin https://github.com/dubhater/vapoursynth-mvtools.git d2c491b3030415c4b416f048e236f5f327d7cb89

# Other entries

configure-plugin https://github.com/Hinterwaeldlers/vapoursynth-hqdn3d.git eb820cb23f7dc47eb67ea95def8a09ab69251d30

ninja-plugin https://github.com/myrsloik/VapourSynth-FFT3DFilter.git R2

git-shallow-clone "r30" https://github.com/EleonoreMizo/fmtconv.git /src/fmtconv
pushd /src/fmtconv
cd build/unix
sed -i 's/ -fexperimental-new-pass-manager//g' configure.ac
./autogen.sh
./configure --prefix=/usr --libdir=/usr/lib/vapoursynth/
make -j$(nproc)
make install

git-shallow-clone "68dc130bc37615fd912d1dc1068261f00f54b146" https://github.com/sekrit-twc/znedi3.git /src/znedi3
pushd /src/znedi3
sed -i -r 's/\(nullptr_t/(std::nullptr_t/g' vsxx/VapourSynth4++.hpp
#TODO: remove X86 hardcode
make X86=1 -j$(nproc)
cp vsznedi3.so /usr/lib/vapoursynth/
cp nnedi3_weights.bin /usr/lib/vapoursynth/

git-shallow-clone "8fe5aec894a3b90224a2014619af8b8c6cf372ad" https://github.com/jackb992/flash3kyuu_deband.git /src/flash3kyuu_deband
pushd /src/flash3kyuu_deband
sed -i 's/env python/env python3/' ./waf
chmod +x waf
./waf configure
./waf build
cp build/libf3kdb.so /usr/lib/vapoursynth/

git-shallow-clone "ef243ab40b8d4b6d18874c6cef0da1a2f55a6a45" https://github.com/FFMS/ffms2.git /src/ffms2
pushd /src/ffms2
./autogen.sh
./configure --prefix=/usr
make -j$(nproc)
make install

curl https://raw.githubusercontent.com/WolframRhodium/muvsfunc/e90bd4e7157aaf32c6ec61ddc60191e75259c3d7/muvsfunc.py > /usr/lib/vapoursynth/muvsfunc.py